@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     test_header
     ~~~~~~~~~~~
@@ -17,9 +16,9 @@ def test_header(app, warning):
     output = (app.outdir / "index.html").read_text(encoding='utf-8')
     pattern1 = (
         '<p class="rubric" '
-        'id="bibtex-bibliography-index-[0-9]+">Regular Citations</p>')
+        'id="[^"]+">Regular Citations</p>')
     pattern2 = (
         '<p class="rubric" '
-        'id="bibtex-footbibliography-index-[0-9]+">Footnote Citations</p>')
+        'id="[^"]+">Footnote Citations</p>')
     assert re.search(pattern1, output) is not None
     assert re.search(pattern2, output) is not None
