@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     test_list_bullet
     ~~~~~~~~~~~~~~~~
@@ -16,10 +15,10 @@ def test_list_bullet(app, warning):
     assert not warning.getvalue()
     output = (app.outdir / "index.html").read_text()
     assert re.search(
-        '<ul .* id="bibtex-bibliography-index-[0-9]+">'
-        '.*<li>.*Akkerdju.*</li>'
-        '.*<li>.*Bro.*</li>'
-        '.*<li>.*Chap.*</li>'
-        '.*<li>.*Dude.*</li>'
+        '<ul'
+        '.*<li.*Akkerdju.*</li>'
+        '.*<li.*Bro.*</li>'
+        '.*<li.*Chap.*</li>'
+        '.*<li.*Dude.*</li>'
         '.*</ul>',
-        output, re.MULTILINE | re.DOTALL)
+        output, re.DOTALL)
